Documentation
¶
Overview ¶
Package commit provides ui to perform a git commit.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DialogContent ¶
type DialogContent struct {
Model
}
DialogContent is a wrapper to use the commit ui as dialog.DialogContent.
func NewContent ¶
func NewContent(commit Model) DialogContent
func (DialogContent) Init ¶
func (dc DialogContent) Init() tea.Cmd
func (DialogContent) View ¶
func (dc DialogContent) View() string
type ExecutedMsg ¶
type ExecutedMsg struct {
Err error
}
ExecutedMsg is the message to be sent after we performed a git commit.
type MergeMsgLoaded ¶
type MergeMsgLoaded struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.